﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using COMTraderInterfacesLib;

namespace Balance
{
    public partial class BalanceForm : Form
    {
        /// <summary>
        /// Objeto COM de trading
        /// </summary>
        private VCT_Trader _Trader;

        public BalanceForm()
        {
            _Trader = null;

            InitializeComponent();
        }

        private void BalanceForm_Load(object sender, EventArgs e)
        {
            // Creación del objeto que gestiona el trading
            try
            {
                _Trader = new VCT_Trader();
                LoadAccounts();
            }
            catch (Exception)
            {
                _Trader = null;
                MessageBox.Show("Error al cargar el servidor COM. Asegúrese de estar conectado al broker antes de ejecutar la aplicación", 
                    "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// Carga en el combo las cuentas existentes y selecciona la primera de ellas
        /// </summary>
        private void LoadAccounts()
        {
            cbAccounts.Items.Clear();
            foreach (VCT_Account account in _Trader.Accounts)
            {
                cbAccounts.Items.Add(account.Account);
            }

            if (cbAccounts.Items.Count > 0)
            {
                cbAccounts.SelectedIndex = 0;
            }
        }

        private void cbAccounts_SelectedIndexChanged(object sender, EventArgs e)
        {
            try
            {
                // Obtención de la cuenta
                if (_Trader != null)
                {
                    string accountText = cbAccounts.SelectedItem.ToString();
                    VCT_Account account = _Trader.Accounts[accountText];
                    if (account != null)
                    {
                        // Descripción de la cuenta
                        lDescription.Text = account.Description;

                        // Valores del balance
                        VCT_Balance balance = account.Balance;
                        string text = string.Format("Cartera = {0:0.#####}\r\n", balance.PortfolioValue) +
                            string.Format("Patrimonio = {0:0.#####}\r\n", balance.NetWorth) +
                            string.Format("Garantías = {0:0.#####}\r\n", balance.Margins) +
                            string.Format("Poder de compra = {0:0.#####}\r\n", balance.OutstandingBalance) +
                            string.Format("Efectivo = {0:0.#####}\r\n", balance.Cash) +
                            string.Format("Efectivo retenido = {0:0.#####}\r\n", balance.MarginCash) +
                            string.Format("Disponible por apalancamiento = {0:0.#####}\r\n", balance.CashByLeverage);
                        tbBalance.Text = text;
                    }
                }
            }
            catch (Exception)
            {
                MessageBox.Show("Error al cargar el servidor COM. Asegúrese de estar conectado al broker antes de ejecutar la aplicación",
                    "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void btnClose_Click(object sender, EventArgs e)
        {
            Close();
        }

    }
}
